@@ -8,7 +8,7 @@ from provider_switch.ssm.ssm_client import SSMClient
 
 class ProviderModel(object):
     _excludes = ['_format_values', 'ssm_client', 'status', 'url', 'headers', 'request', 'response',
-        'retry_when_not_found']
+                 'retry_when_not_found']
 
     def __init__(self, **kwargs):
         self.id = kwargs.get('id', None)
@@ -155,6 +155,9 @@ class ProviderModel(object):
         # self.ssm_client.set_providers(self.to_json())
         pass
 
+    def set_active(self):
+        self.status = True
+
     def sync(self, provider_data):
         self.ssm_client.set_providers(provider={**self.to_json(), **provider_data})
 
