@@ -228,7 +228,7 @@ class ProviderSwitchHandler(object):
                 provider.increment_session_fail()
                 return self._make_request(variables)
             else:
-                pass
+                return None
 
         except BadProviderException as e:
             print('BadProviderException: ', e.message)
@@ -240,7 +240,7 @@ class ProviderSwitchHandler(object):
                     print(f'Error sync parameter: {str(e)}')
                 return self._make_request(variables)
             else:
-                pass
+                return None
 
         except ExitException as e:
             print('ExitException: ', e.message)
@@ -250,6 +250,10 @@ class ProviderSwitchHandler(object):
             print('Exception: ', e)
             return None
 
+    def _refresh_providers_status(self):
+        for i in range(len(self.providers)):
+            self.providers[i].set_active()
+
     def get(self, variables: dict = None) -> dict:
         """GET request
 
@@ -259,4 +263,6 @@ class ProviderSwitchHandler(object):
         Returns:
             dict: _description_
         """
-        return self._make_request(variables=variables or {})
+        result = self._make_request(variables=variables or {})
+        self._refresh_providers_status()
+        return result
